document.addEventListener('DOMContentLoaded', () => {
    const API_KEY = '936cb540e306a6b0fa112b4c77df57eb'; // <-- PASTE YOUR API KEY HERE

    // Get DOM Elements
    const locationNameEl = document.getElementById('location-name');
    const currentTempEl = document.getElementById('current-temp');
    const currentDescriptionEl = document.getElementById('current-description');
    const verticalDescriptionEl = document.getElementById('weather-description-vertical');
    const hourlyContainerEl = document.getElementById('hourly-container');
    const weatherAppEl = document.getElementById('weather-app');
    const searchFormEl = document.getElementById('search-form');
    const searchInputEl = document.getElementById('search-input');
    const menuBtnEl = document.getElementById('menu-btn');
    const historyPanelEl = document.getElementById('history-panel');
    const closeHistoryBtnEl = document.getElementById('close-history-btn');
    const historyListEl = document.getElementById('history-list');

    // State
    let searchHistory = JSON.parse(localStorage.getItem('weatherSearchHistory')) || [];

    const weatherIconMap = {
        '01d': 'https://openweathermap.org/img/wn/01d@2x.png',
        '01n': 'https://openweathermap.org/img/wn/01n@2x.png',
        '02d': 'https://openweathermap.org/img/wn/02d@2x.png',
        '02n': 'https://openweathermap.org/img/wn/02n@2x.png',
        '03d': 'https://openweathermap.org/img/wn/03d@2x.png',
        '03n': 'https://openweathermap.org/img/wn/03n@2x.png',
        '04d': 'https://openweathermap.org/img/wn/04d@2x.png',
        '04n': 'https://openweathermap.org/img/wn/04n@2x.png',
        '09d': 'https://openweathermap.org/img/wn/09d@2x.png',
        '09n': 'https://openweathermap.org/img/wn/09n@2x.png',
        '10d': 'https://openweathermap.org/img/wn/10d@2x.png',
        '10n': 'https://openweathermap.org/img/wn/10n@2x.png',
        '11d': 'https://openweathermap.org/img/wn/11d@2x.png',
        '11n': 'https://openweathermap.org/img/wn/11n@2x.png',
        '13d': 'https://openweathermap.org/img/wn/13d@2x.png',
        '13n': 'https://openweathermap.org/img/wn/13n@2x.png',
        '50d': 'https://openweathermap.org/img/wn/50d@2x.png',
        '50n': 'https://openweathermap.org/img/wn/50n@2x.png'
    };

    const fetchWeatherByCoords = async (lat, lon) => {
        const weatherUrl = `https://api.openweathermap.org/data/2.5/weather?lat=${lat}&lon=${lon}&appid=${API_KEY}&units=metric`;
        const forecastUrl = `https://api.openweathermap.org/data/2.5/forecast?lat=${lat}&lon=${lon}&appid=${API_KEY}&units=metric`;
        fetchAndProcessWeather(weatherUrl, forecastUrl);
    };

    const fetchWeatherByCity = async (city) => {
        const weatherUrl = `https://api.openweathermap.org/data/2.5/weather?q=${city}&appid=${API_KEY}&units=metric`;
        const forecastUrl = `https://api.openweathermap.org/data/2.5/forecast?q=${city}&appid=${API_KEY}&units=metric`;
        fetchAndProcessWeather(weatherUrl, forecastUrl, true);
    };

    const fetchAndProcessWeather = async (weatherUrl, forecastUrl, fromSearch = false) => {
        try {
            const [weatherResponse, forecastResponse] = await Promise.all([
                fetch(weatherUrl),
                fetch(forecastUrl)
            ]);

            if (!weatherResponse.ok) {
                const errorData = await weatherResponse.json();
                throw new Error(errorData.message || 'City not found.');
            }
             if (!forecastResponse.ok) {
                throw new Error('Forecast data not available.');
            }

            const weatherData = await weatherResponse.json();
            const forecastData = await forecastResponse.json();
            
            updateUI(weatherData, forecastData);
            
            if (fromSearch) {
                addToHistory(weatherData.name);
            }

        } catch (error) {
            console.error("Error fetching weather data:", error);
            alert(`Error: ${error.message}`);
            locationNameEl.textContent = "Error";
            currentDescriptionEl.textContent = "Could not fetch data.";
        }
    };

    const updateUI = (weather, forecast) => {
        locationNameEl.textContent = `${weather.name}, ${weather.sys.country}`;
        const temp = Math.round(weather.main.temp);
        currentTempEl.innerHTML = `${temp}°`;
        
        const description = weather.weather[0].description;
        currentDescriptionEl.textContent = description;
        verticalDescriptionEl.textContent = description.split(' ').map(word => word.charAt(0).toUpperCase() + word.slice(1)).join(' ');

        const isDay = weather.weather[0].icon.includes('d');
        weatherAppEl.classList.remove('day', 'night');
        weatherAppEl.classList.add(isDay ? 'day' : 'night');
        
        // Close panel if it's open
        closeHistoryPanel();

        hourlyContainerEl.innerHTML = '';
        const hourlyForecasts = forecast.list.slice(0, 5);

        hourlyForecasts.forEach(item => {
            const date = new Date(item.dt * 1000);
            const hour = date.getHours().toString().padStart(2, '0');
            const iconSrc = weatherIconMap[item.weather[0].icon] || weatherIconMap['01d'];
            
            const hourlyItemHtml = `
                <div class="hourly-item">
                    <div class="hour-time">${hour}:00</div>
                    <img src="${iconSrc}" alt="${item.weather[0].description}" class="hour-icon">
                    <div class="hour-temp">${Math.round(item.main.temp)}°</div>
                </div>
            `;
            hourlyContainerEl.innerHTML += hourlyItemHtml;
        });
    };
    
    const addToHistory = (city) => {
        const normalizedCity = city.toLowerCase();
        // Remove city if it already exists to move it to the top
        searchHistory = searchHistory.filter(h => h.toLowerCase() !== normalizedCity);
        // Add to the beginning of the array
        searchHistory.unshift(city);
        // Limit history to 10 items
        if (searchHistory.length > 10) {
            searchHistory.pop();
        }
        localStorage.setItem('weatherSearchHistory', JSON.stringify(searchHistory));
        renderHistory();
    };

    const renderHistory = () => {
        historyListEl.innerHTML = '';
        if (searchHistory.length === 0) {
            historyListEl.innerHTML = '<li>No recent searches.</li>';
            return;
        }
        searchHistory.forEach(city => {
            const li = document.createElement('li');
            li.textContent = city;
            li.addEventListener('click', () => {
                fetchWeatherByCity(city);
                closeHistoryPanel();
            });
            historyListEl.appendChild(li);
        });
    };

    const getLocation = () => {
        if (navigator.geolocation) {
            navigator.geolocation.getCurrentPosition(
                (position) => {
                    fetchWeatherByCoords(position.coords.latitude, position.coords.longitude);
                },
                (error) => {
                    console.error("Geolocation error:", error);
                    fetchWeatherByCity("London");
                }
            );
        } else {
            console.error("Geolocation is not supported.");
            fetchWeatherByCity("London");
        }
    };
    
    // --- MODIFIED: Panel Control Functions ---
    const openHistoryPanel = () => {
        menuBtnEl.classList.add('open');
        historyPanelEl.classList.add('active');
        // Listen for the transition to end, THEN add the blur
        historyPanelEl.addEventListener('transitionend', () => {
            historyPanelEl.classList.add('blur-active');
        }, { once: true }); // {once: true} automatically removes the listener after it fires
    };

    const closeHistoryPanel = () => {
        menuBtnEl.classList.remove('open');
        // First, remove the blur class INSTANTLY
        historyPanelEl.classList.remove('blur-active');
        // Then, start the slide-out animation
        historyPanelEl.classList.remove('active');
    };

    // Event Listeners
    searchFormEl.addEventListener('submit', (e) => {
        e.preventDefault();
        const city = searchInputEl.value.trim();
        if (city) {
            fetchWeatherByCity(city);
            searchInputEl.value = '';
        }
    });

    menuBtnEl.addEventListener('click', () => {
        // --- MODIFIED ---
        if (historyPanelEl.classList.contains('active')) {
            closeHistoryPanel();
        } else {
            openHistoryPanel();
        }
    });

    closeHistoryBtnEl.addEventListener('click', closeHistoryPanel); // --- MODIFIED ---

    // Initial Load
    renderHistory();
    getLocation();
});


// preloader
window.addEventListener("load", function() {
  // Minimum 2 seconds delay
  setTimeout(function() {
    const preloader = document.getElementById("preloader");
    preloader.style.display = "none";

    const app = document.getElementById("app");
    app.style.display = "block";
  }, 2500); // 2500 ms = 2.5 sec
});

